title:      PDF Documents
desc:       Docnado Markdown Quick Reference
date:       2018/10/12
version:    1.0.0
template:   document
nav:        Document>PDF Documents
percent:    100
authors:    enq@heinventions.com


You might want to embed a PDF, but obviously, its no docnado!

```markdown
![](assets/example.pdf)

![](assets/example.pdf){: .landscape}
```

![](assets/example.pdf)

![](assets/example.pdf){: .landscape}

You can add a `{: .landscape}` property to these in order to change the aspect ratio. Only the `A4` paper aspect is currently supported.
{:.tip}
